package de.ozgcloud.nachrichten;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import de.ozgcloud.apilib.common.command.OzgCloudCommandService;
import de.ozgcloud.apilib.common.command.grpc.CommandMapper;
import de.ozgcloud.apilib.common.command.grpc.GrpcOzgCloudCommandService;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.file.grpc.GrpcOzgCloudFileService;
import de.ozgcloud.apilib.file.grpc.OzgCloudFileMapper;
import de.ozgcloud.vorgang.grpc.binaryFile.BinaryFileServiceGrpc.BinaryFileServiceBlockingStub;
import de.ozgcloud.vorgang.grpc.binaryFile.BinaryFileServiceGrpc.BinaryFileServiceStub;
import de.ozgcloud.vorgang.grpc.command.CommandServiceGrpc;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Configuration
public class NachrichtenManagerConfiguration {

	public static final String OZG_CLOUD_COMMAND_SERVICE_NAME = "nachrichten_OzgCloudCommandService";
	public static final String OZG_CLOUD_FILE_SERVICE_NAME = "nachrichten_OzgCloudFileService";

	public static final String NACHRICHTEN_VORGANG_SERVICE = "nachrichten_vorgangService";
	public static final String NACHRICHTEN_VORGANG_REMOTE_SERVICE = "nachrichten_vorgangRemoteService";
	public static final String NACHRICHTEN_ATTACHED_ITEM_SERVICE = "nachrichten_attachedItemService";
	public static final String NACHRICHTEN_OZG_CLOUD_FILE_MAPPER = "nachrichten_OzgCloudFileMapperImpl";

	public static final String GRPC_VORGANG_MANAGER_NAME = "vorgang-manager";
	public static final String GRPC_COMMAND_MANAGER_NAME = "command-manager";
	public static final String GRPC_FILE_MANAGER_NAME = "file-manager";

	@GrpcClient(GRPC_COMMAND_MANAGER_NAME)
	private CommandServiceGrpc.CommandServiceBlockingStub commandServiceStub;

	@GrpcClient(GRPC_FILE_MANAGER_NAME)
	private BinaryFileServiceBlockingStub fileServiceBlockingStub;
	@GrpcClient(GRPC_FILE_MANAGER_NAME)
	private BinaryFileServiceStub fileServiceAsyncServiceStub;

	@Bean(OZG_CLOUD_COMMAND_SERVICE_NAME)
	OzgCloudCommandService grpcOzgCloudCommandService(CommandMapper commandMapper, NachrichtenManagerCallContextProvider contextProvider) {
		return new GrpcOzgCloudCommandService(commandServiceStub, commandMapper, contextProvider,
				GrpcOzgCloudCommandService.DEFAULT_COMMAND_REQUEST_THRESHOLD_MILLIS);
	}

	@Bean(OZG_CLOUD_FILE_SERVICE_NAME)
	OzgCloudFileService grpcOzgCloudFileService(NachrichtenManagerCallContextProvider contextProvider, OzgCloudFileMapper mapper) {
		return new GrpcOzgCloudFileService(fileServiceBlockingStub, fileServiceAsyncServiceStub, contextProvider, mapper);
	}
}