package de.ozgcloud.nachrichten.common.vorgang;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.vorgang.vorgang.GrpcPostfachAddress;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangHead;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangWithEingang;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN)
interface NachrichtenVorgangMapper {

	@Mapping(target = "trustLevel", source = "vorgangWithEingang.header.serviceKonto.trustLevel")
	@Mapping(target = "postfachId", expression = "java(getPostfachId(vorgangWithEingang.getHeader()))")
	Vorgang fromVorgangWithEingang(GrpcVorgangWithEingang vorgangWithEingang);

	default String getPostfachId(GrpcVorgangHead head) {
		return head.getServiceKonto().getPostfachAddressesList().stream()
				.map(this::getPostfachId).findFirst()
				.orElse(StringUtils.EMPTY);
	}

	default String getPostfachId(GrpcPostfachAddress address) {
		return address.getIdentifier().getPropertyList().stream()
				.filter(prop -> Vorgang.POSTFACH_ID_FIELD.equals(prop.getName()))
				.map(prop -> prop.getValue(0))
				.findFirst()
				.orElse(StringUtils.EMPTY);
	}
}