/*
 * Copyright (c) 2024.
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.antragraum;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.springframework.core.io.InputStreamResource;
import org.springframework.test.util.ReflectionTestUtils;

import de.ozgcloud.common.test.TestUtils;

class Saml2VerifierTest {
	private String samlResponse;

	private Saml2Verifier verifier;

	@Mock
	private AntragraumProperties properties;

	private BayernIdSamlConfiguration configuration;

	@BeforeEach
	void setup() throws Exception {
		when(properties.getMetadataUri()).thenReturn(new InputStreamResource(TestUtils.loadFile("bayernid-idp-infra.xml")));
		when(properties.getEntityId()).thenReturn("https://antragsraum.ozgcloud.de");
		samlResponse = TestUtils.loadTextFile("SamlResponse.xml");

		configuration = new BayernIdSamlConfiguration();
		ReflectionTestUtils.setField(configuration, "antragraumProperties", properties);
		configuration.initOpenSAML();

		var parser = new Saml2Parser(configuration);

		verifier = new Saml2Verifier(parser, configuration);
		verifier.init();
	}

	@Test
	void shouldGetVerificationError() {
		var res = verifier.verify(samlResponse);

		assertThat(res).isNotEmpty();
	}
}